/*----------------------------------------------------------------------------
 *      main Template for CMSIS RTE C/C++ Project
 *----------------------------------------------------------------------------
 *      Name:    main.c
 *      Purpose: Generic main program body including main() function
 *      Rev.:    1.0.0
 *----------------------------------------------------------------------------*/
/*******************************************************************************
* Copyright (c) 2017 ARM Ltd. and others
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
* ARM Ltd and ARM Germany GmbH - file template
*******************************************************************************/

#ifdef _RTE_
  #include "RTE_Components.h"             // Component selection
  #include CMSIS_device_header
#endif
#ifdef RTE_CMSIS_RTOS                     // when RTE component CMSIS RTOS is used
  #include "cmsis_os.h"                   // CMSIS RTOS header file
#endif
#include <stdio.h>
#include "Board_LED.h"
#include "Board_Buttons.h"

/*----------------------------------------------------------------------------
 *      Thread LED
 *---------------------------------------------------------------------------*/
void thread_LED (void  const *argument) {
  uint32_t led_cnt = LED_GetCount();
  uint32_t led_num = 0;

  for (;;) {

	while (Buttons_GetState() != 0);  /* Wait while holding any USER button */

    LED_On(led_num);                  // Turn specified LED on
    osDelay(100);
    led_num++;                        // Change LED number
    if (led_num >= led_cnt) {
      led_num = 0;                    // Restart with first LED
      LED_SetOut (0);
      osDelay(500);                   // Turn specified LED off

      printf("Hello World!\n");

    }
  }
}

osThreadDef(thread_LED,  osPriorityNormal, 1, 0);

/* main function */
int main(void)
{
  SystemCoreClockUpdate();

#ifdef RTE_CMSIS_RTOS                   // when using CMSIS RTOS
  osKernelInitialize ();                // initialize CMSIS-RTOS
#endif

  /* Initialize device HAL here */
  LED_Initialize();                     /* LED Initialization             */
  Buttons_Initialize();                 /* Buttons Initialization         */
  
#ifdef RTE_CMSIS_RTOS                   // when using CMSIS RTOS
  // create 'thread' functions that start executing,
  // example: tid_name = osThreadCreate (osThread(name), NULL);
  osThreadCreate(osThread(thread_LED),  NULL);
  osKernelStart ();                     // start thread execution 
#endif

  /* Infinite loop */
  while (1)
  {
    /* Add application code here */
  }

}

