/*-----------------------------------------------------------------------------
 * Name:    Buttons_TWR-VF65GS10.c
 * Purpose: Buttons interface
 * Rev.:    1.00
 *----------------------------------------------------------------------------*/

/* Copyright (c) 2013 - 2017 ARM LIMITED

   All rights reserved.
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
   - Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
   - Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
   - Neither the name of ARM nor the names of its contributors may be used
     to endorse or promote products derived from this software without
     specific prior written permission.
   *
   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL COPYRIGHT HOLDERS AND CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
   ---------------------------------------------------------------------------*/

#ifdef _RTE_
  #include "RTE_Components.h"           // Component selection
  #include CMSIS_device_header
#endif
#include "Board_Buttons.h"              // ::Board Support:Buttons

#define NUM_KEYS  3                     /* Number of available keys           */

/* Keys for SAMV7-XPRO */
#define KEY_SW1    (1 << 0)             /* Represent PTB16 (SW1) */
#define KEY_SW2    (1 << 1)             /* Represent PTB17 (SW2) */
#define KEY_SW4    (1 << 2)             /* Represent PTD6  (SW4) */

#define PIN_MASK            0x1Fu
#define PIN(x)              (unsigned)(((1)<<(x & PIN_MASK)))

/**
  \fn          int32_t Buttons_Initialize (void)
  \brief       Initialize buttons
  \returns
   - \b  0: function succeeded
   - \b -1: function failed
*/
int32_t Buttons_Initialize (void) {

  IOMUXC->SINGLE.PTB16 = IOMUXC_PTB16_PUS(0x1)|IOMUXC_PTB16_PKE_MASK|IOMUXC_PTB16_PUE_MASK|IOMUXC_PTB16_IBE_MASK; //enable GPIO input for PTB16
  IOMUXC->SINGLE.PTB17 = IOMUXC_PTB17_PUS(0x1)|IOMUXC_PTB17_PKE_MASK|IOMUXC_PTB17_PUE_MASK|IOMUXC_PTB17_IBE_MASK; //enable GPIO input for PTB17
  IOMUXC->SINGLE.PTD6  = IOMUXC_PTD6_PUS(0x1) |IOMUXC_PTD6_PKE_MASK |IOMUXC_PTD6_PUE_MASK |IOMUXC_PTD6_IBE_MASK;  //enable GPIO input for PTD6

  return (0);
}


/**
  \fn          int32_t Buttons_Uninitialize (void)
  \brief       De-initialize buttons
  \returns
   - \b  0: function succeeded
   - \b -1: function failed
*/
int32_t Buttons_Uninitialize (void) {

  return (0);
}


/**
  \fn          uint32_t Buttons_GetState (void)
  \brief       Get buttons state
  \returns     Buttons state
*/
uint32_t Buttons_GetState (void) {

  uint32_t val = 0;

  if((GPIO1->PDIR & GPIO_PDIR_PDI(PIN(6)))==0) {
    val |= KEY_SW1;
  }
  if((GPIO1->PDIR & GPIO_PDIR_PDI(PIN(7)))==0) {
	val |= KEY_SW2;
  }
  if((GPIO2->PDIR & GPIO_PDIR_PDI(PIN(21)))==0) {
	val |= KEY_SW2;
  }

  return (val);
}


/**
  \fn          uint32_t Buttons_GetCount (void)
  \brief       Get number of available buttons
  \return      Number of available buttons
*/
uint32_t Buttons_GetCount (void) {
  return (NUM_KEYS);
}

