/*----------------------------------------------------------------------------
 *      main Template for CMSIS RTE C/C++ Project
 *----------------------------------------------------------------------------
 *      Name:    main.c
 *      Purpose: Generic main program body including main() function
 *      Rev.:    1.0.0
 *----------------------------------------------------------------------------*/
/*******************************************************************************
* Copyright (c) 2017 ARM Ltd. and others
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
* ARM Ltd and ARM Germany GmbH - file template
*******************************************************************************/

#ifdef _RTE_
  #include "RTE_Components.h"             // Component selection
  #include CMSIS_device_header
#endif
#ifdef RTE_CMSIS_RTOS                     // when RTE component CMSIS RTOS is used
  #include "cmsis_os.h"                   // CMSIS RTOS header file
#endif
#include <stdio.h>
#include "Board_LED.h"

/*----------------------------------------------------------------------------
 *      Thread LED
 *---------------------------------------------------------------------------*/
void thread_LED (void  const *argument) {

  for (;;) {

    LED_On(0);                          // Turn specified LED on
    osDelay(500);
    LED_Off(0);                         // Turn specified LED off
    osDelay(500);

    printf("Hello World!\n");

  }
}

osThreadDef(thread_LED,  osPriorityNormal, 1, 0);

/* main function */
int main(void)
{
  SystemCoreClockUpdate();

#ifdef RTE_CMSIS_RTOS                   // when using CMSIS RTOS
  osKernelInitialize ();                // initialize CMSIS-RTOS
#endif

  /* Initialize device HAL here */
  LED_Initialize();                     /* LED Initialization             */

#ifdef RTE_CMSIS_RTOS                   // when using CMSIS RTOS
  // create 'thread' functions that start executing,
  // example: tid_name = osThreadCreate (osThread(name), NULL);
  osThreadCreate(osThread(thread_LED),  NULL);
  osKernelStart ();                     // start thread execution 
#endif

  /* Infinite loop */
  while (1)
  {
    /* Add application code here */
  }

}

